*****************
General utilities
*****************

.. toctree::
    :maxdepth: 1

    tools/files.rst
    tools/logger.rst
    tools/testing.rst
    tools/py_utils.rst
    tools/fits_utils.rst
    tools/catalogs.rst
